@@ -2,7 +2,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2004-2024 Univention GmbH
+# Copyright 2004-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -205,7 +205,7 @@ def ocToType(oc):
     for module in univention.admin.modules.modules.values():
         if univention.admin.modules.policyOc(module) == oc:
             return univention.admin.modules.name(module)
-    return None  # FIXME
+    return None  # FIXME:
 
 
 def fixedAttribute(object, key):
@@ -332,7 +332,7 @@ def wantsCleanup(object):
     :param object: parent object.
     :returns: `True´ if a cleanup is requested, `False` otherwise.
     """
-    # TODO make this a method of object
+    # TODO: make this a method of object
     wantsCleanup = False
 
     object_module = module(object)
