@@ -2,7 +2,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2004-2024 Univention GmbH
+# Copyright 2004-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -110,7 +110,7 @@ class DN:
         # compute hash only once - object is static
         # TODO: attributes which's values are case insensitive should be respected
         if self._hash is None:
-            self._hash = hash(tuple([tuple(sorted((x.lower(), y, z) for x, y, z in rdn)) for rdn in self._dn]))
+            self._hash = hash(tuple(tuple(sorted((x.lower(), y, z) for x, y, z in rdn)) for rdn in self._dn))
         return self._hash
 
     @classmethod
